/* BdfServer_Commands - Copyright (c) 2015-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.corpus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.FichothequeEditor;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.corpus.CorpusEditor;
import net.fichotheque.corpus.FicheMeta;
import net.fichotheque.namespaces.BdfSpace;
import net.fichotheque.tools.FichothequeTools;
import net.mapeadores.util.attr.Attribute;
import net.mapeadores.util.attr.AttributeBuilder;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public class FicheRemoveCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "FicheRemove";
    public final static String COMMANDKEY = "_ CRP-11";
    public final static String DISCARDTEXT_PARAMNAME = "discardtext";
    private FicheMeta ficheMeta;
    private Attribute discardAttribute;

    public FicheRemoveCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.CORPUS + "/" + COMMANDNAME);
        FichothequeEditor fichothequeEditor = editSession.getFichothequeEditor();
        fichothequeEditor.putAttribute(ficheMeta, discardAttribute);
        int ficheid = ficheMeta.getId();
        for (Corpus corpus : ficheMeta.getCorpus().getSatelliteCorpusList()) {
            FicheMeta satelliteFicheMeta = corpus.getFicheMetaById(ficheid);
            if (satelliteFicheMeta != null) {
                fichothequeEditor.putAttribute(satelliteFicheMeta, discardAttribute);
            }
        }
        fichothequeEditor.saveChanges();
        FichothequeTools.prepareToRemove(fichothequeEditor, ficheMeta);
        Corpus corpus = ficheMeta.getCorpus();
        CorpusEditor corpusEditor = fichothequeEditor.getCorpusEditor(corpus.getSubsetKey());
        corpusEditor.removeFiche(ficheMeta);
        setDone("_ done.corpus.ficheremove");
        putResultObject(CORPUS_OBJ, corpus);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        ficheMeta = BdfInstructionUtils.getMandatoryFicheMeta(fichotheque, requestMap);
        checkSubsetAdminPermission(ficheMeta.getCorpus());
        String discardText = getMandatory(DISCARDTEXT_PARAMNAME);
        String[] tokens = StringUtils.getLineTokens(discardText, StringUtils.EMPTY_EXCLUDE);
        if (tokens.length == 0) {
            setError("_ error.empty.discardtext_remove");
            return false;
        }
        if (!BdfInstructionUtils.checkConfirmation(requestMap, bdfServer)) {
            setError("_ error.empty.confirmationcheck_remove");
            return false;
        }
        AttributeBuilder builder = new AttributeBuilder(BdfSpace.DISCARDTEXT_KEY);
        for (String token : tokens) {
            builder.addValue(token);
        }
        this.discardAttribute = builder.toAttribute();
        return true;
    }


}
