/* BdfServer_Commands - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.selection;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.selection.FicheQuery;
import net.fichotheque.selection.MotcleQuery;
import net.fichotheque.thesaurus.Motcle;
import net.fichotheque.tools.selection.FicheQueryBuilder;
import net.fichotheque.tools.selection.MotcleQueryBuilder;
import net.fichotheque.utils.ThesaurusUtils;
import net.mapeadores.util.conditions.Condition;
import net.mapeadores.util.conditions.ConditionsConstants;
import net.mapeadores.util.conditions.ConditionsUtils;
import net.mapeadores.util.primitives.Range;
import net.mapeadores.util.primitives.Ranges;
import net.mapeadores.util.request.RequestMap;
import net.fichotheque.corpus.SortConstants;


/**
 *
 * @author Vincent Calame
 */
public class SelectionByMotcleCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "SelectionByMotcle";
    private Motcle motcle;

    public SelectionByMotcleCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return false;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        FicheQuery ficheQuery = toFicheQuery();
        bdfServer.setFicheSelection(bdfUser, ficheQuery, SortConstants.ID);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        motcle = BdfInstructionUtils.getMandatoryMotcle(fichotheque, requestMap);
        return true;
    }

    private FicheQuery toFicheQuery() {
        MotcleQueryBuilder motcleQueryBuilder = new MotcleQueryBuilder();
        if (ThesaurusUtils.isIdalphaType(motcle.getThesaurus())) {
            String idalpha = motcle.getIdalpha();
            Condition condition = ConditionsUtils.parseCondition(idalpha, ConditionsConstants.MODE_AND);
            motcleQueryBuilder.setContentCondition(condition, MotcleQuery.ONLY_IDALPHA_SCOPE);
        } else {
            Ranges ranges = new Ranges();
            ranges.addRange(new Range(motcle.getId(), motcle.getId()));
            motcleQueryBuilder.setIdRangeList(ranges);
        }
        motcleQueryBuilder
                .addThesaurus(motcle.getThesaurus())
                .setIncludeSatellites(true);
        return FicheQueryBuilder.init()
                .addIndexationMotcleQuery(motcleQueryBuilder.toMotcleQuery())
                .toFicheQuery();
    }

}
