/* BdfServer_Commands - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.thesaurus.Thesaurus;
import net.fichotheque.thesaurus.metadata.ThesaurusMetadataEditor;
import net.mapeadores.util.localisation.Langs;
import net.mapeadores.util.localisation.LangsUtils;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class ThesaurusLangListCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "ThesaurusLangList";
    public final static String COMMANDKEY = "_ THS-03";
    public final static String LANGLIST_PARAMNAME = "langlist";
    private Thesaurus thesaurus;
    private Langs langs;

    public ThesaurusLangListCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.THESAURUS + "/" + COMMANDNAME);
        ThesaurusMetadataEditor thesaurusMetadataEditor = editSession.getFichothequeEditor().getThesaurusEditor(thesaurus.getSubsetKey()).getThesaurusMetadataEditor();
        boolean done = thesaurusMetadataEditor.setAuthorizedLangs(langs);
        if (done) {
            setDone("_ done.thesaurus.langlist");
        }
        putResultObject(THESAURUS_OBJ, thesaurus);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        thesaurus = BdfInstructionUtils.getMandatoryThesaurus(fichotheque, requestMap);
        checkSubsetAdminPermission(thesaurus);
        String langListString = getMandatory(LANGLIST_PARAMNAME);
        langs = LangsUtils.toCleanLangs(langListString);
        if (langs.size() == 0) {
            setError("_ error.empty.langlist");
            return false;
        }
        return true;
    }

}
