/* BdfServer_HtmlProducers - Copyright (c) 2010-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.edition;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.jslib.FicheJsLibs;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.JsObject;


/**
 *
 * @author Vincent Calame
 */
public class ZoomEditHtmlProducer extends BdfServerHtmlProducer {

    private final String appelant;

    public ZoomEditHtmlProducer(ProducerParameters producerParameters, String appelant) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser(), appelant);
    }

    public ZoomEditHtmlProducer(BdfServer bdfServer, BdfUser bdfUser, String appelant) {
        super(bdfServer, bdfUser);
        addJsLib(FicheJsLibs.ZOOMEDIT);
        addThemeCss("ficheform.css", "zoomedit.css");
        this.appelant = appelant;
        setBodyCssClass("global-body-TopBorder");
    }

    @Override
    public void printHtml() {
        String clientId = generateId();
        JsObject args = JsObject.init()
                .put("clientId", clientId)
                .put("appelant", appelant);
        start();
        this
                .SCRIPT()
                .__jsObject("Zoomedit.ARGS", args)
                ._SCRIPT();
        this
                .DIV(HA.id(clientId).classes("zoomedit-Client"))
                ._DIV();
        end();
    }

}
