/* BdfServer_HtmlProducers - Copyright (c) 2013-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.importation;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.domains.ImportationDomain;
import fr.exemole.bdfserver.api.subsettree.SubsetTree;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.commands.importation.ThesaurusImportParseCommand;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.consumers.Grid;
import fr.exemole.bdfserver.html.consumers.SubsetTreeOptions;
import fr.exemole.bdfserver.html.jslib.CommonJsLibs;
import fr.exemole.bdfserver.html.jslib.MiscJsLibs;
import net.fichotheque.SubsetKey;
import net.fichotheque.importation.ThesaurusImport;
import net.mapeadores.util.html.CommandBox;
import net.mapeadores.util.html.HtmlAttributes;
import net.mapeadores.util.html.HtmlConstants;


/**
 *
 * @author Vincent Calame
 */
public class ThesaurusImportHtmlProducer extends BdfServerHtmlProducer {

    public ThesaurusImportHtmlProducer(ProducerParameters producerParameters) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser());
    }

    public ThesaurusImportHtmlProducer(BdfServer bdfServer, BdfUser bdfUser) {
        super(bdfServer, bdfUser);
        addJsLib(CommonJsLibs.DEPLOY);
        addJsLib(MiscJsLibs.IMPORTATION);
        addThemeCss("importation.css");
        setMainStorageKey(Domains.IMPORTATION, ImportationDomain.THESAURUSIMPORT_PAGE);
    }

    @Override
    public void printHtml() {
        start();
        printCommandMessageUnit();
        SubsetTree thesaurusTree = bdfServer.getTreeManager().getSubsetTree(SubsetKey.CATEGORY_THESAURUS);
        CommandBox commandBox = CommandBox.init()
                .action(Domains.IMPORTATION)
                .family("THS")
                .page(ImportationDomain.IMPORTATION_CONFIRM_PAGE).target(HtmlConstants.BLANK_TARGET)
                .name(ThesaurusImportParseCommand.COMMANDNAME).lockey(ThesaurusImportParseCommand.COMMANDKEY)
                .submitLocKey("_ submit.importation.parse");
        this
                .__start(commandBox)
                .__(Grid.START)
                .__(Grid.selectRow("_ label.importation.thesaurus", name(ThesaurusImportParseCommand.THESAURUS_PARAMNAME).attr("data-subset", "selection"),
                        SubsetTreeOptions.init(thesaurusTree, bdfServer, workingLang)
                                .onlyNames(true)
                                .selectedSet(null)
                                .withKeys(true))
                )
                .__(Grid.choiceSetRow("_ label.importation.thesaurusimporttype", () -> {
                    this
                            .__(printTypeRadio(ThesaurusImport.CREATION_TYPE, "_ label.importation.thesaurusimporttype_creation", true))
                            .__(printTypeRadio(ThesaurusImport.CHANGE_TYPE, "_ label.importation.thesaurusimporttype_change", false))
                            .__(printTypeRadio(ThesaurusImport.REMOVE_TYPE, "_ label.importation.thesaurusimporttype_remove", false))
                            .__(printTypeRadio(ThesaurusImport.MERGE_TYPE, "_ label.importation.thesaurusimporttype_merge", false))
                            .__(printMoveRadio(thesaurusTree));
                }))
                .__(ImportationHtmlUtils.printImportParseRows(this))
                .__(Grid.END)
                .__end(commandBox);
        end();
    }

    private boolean printTypeRadio(String type, String messageKey, boolean checked) {
        HtmlAttributes radio = name(ThesaurusImportParseCommand.TYPE_PARAMNAME).value(type).checked(checked);
        this
                .__(Grid.radioCell(messageKey, radio));
        return true;
    }

    private boolean printMoveRadio(SubsetTree thesaurusTree) {
        HtmlAttributes radio = name(ThesaurusImportParseCommand.TYPE_PARAMNAME).value(ThesaurusImport.MOVE_TYPE);
        this
                .__(Grid.radioCell("_ label.importation.thesaurusimporttype_move", radio,
                        () -> {
                            this
                                    .__(Grid.START)
                                    .__(Grid.selectRow("_ label.importation.destinationthesaurus", name(ThesaurusImportParseCommand.DESTINATIONTHESAURUS_PARAMNAME),
                                            SubsetTreeOptions.init(thesaurusTree, bdfServer, workingLang)
                                                    .onlyNames(true)
                                                    .withKeys(true)))
                                    .__(Grid.END);
                        }));
        return true;
    }


}
