/* FichothequeLib_Xml - Copyright (c) 2011-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.xml.extraction;

import java.io.IOException;
import java.util.List;
import net.fichotheque.album.Album;
import net.fichotheque.extraction.def.ExtraitAlbumDef;
import net.fichotheque.extraction.run.ExtraitAlbumResult;
import net.fichotheque.extraction.run.IllustrationExtractInfo;
import net.mapeadores.util.xml.XMLPart;
import net.mapeadores.util.xml.XMLWriter;


/**
 *
 * @author Vincent Calame
 */
public class ExtraitAlbumXMLPart extends XMLPart {

    private final IllustrationXMLPart illustrationXMLPart;

    public ExtraitAlbumXMLPart(XMLWriter xmlWriter) {
        super(xmlWriter);
        illustrationXMLPart = new IllustrationXMLPart(xmlWriter);
    }

    public void addExtraitAlbum(ExtraitAlbumResult extraitAlbumResult) throws IOException {
        ExtraitAlbumDef extraitAlbumDef = extraitAlbumResult.getExtraitAlbumDef();
        String tagName = extraitAlbumDef.getTagName();
        boolean withTag = (tagName != null);
        int albumCount = extraitAlbumResult.getAlbumCount();
        String extraitName = extraitAlbumDef.getExtraitName();
        if (extraitName != null) {
            if (withTag) {
                startOpenTag(tagName);
                addAttribute("extrait-name", extraitName);
                endOpenTag();
            }
            for (int j = 0; j < albumCount; j++) {
                List<IllustrationExtractInfo> list = extraitAlbumResult.getIllustrationExtractInfoList(j);
                for (IllustrationExtractInfo illustrationExtractInfo : list) {
                    illustrationXMLPart.addIllustration(illustrationExtractInfo);
                }
            }
            if (withTag) {
                closeTag(tagName);
            }
        } else {
            for (int j = 0; j < albumCount; j++) {
                Album thesaurus = extraitAlbumResult.getAlbum(j);
                if (withTag) {
                    startOpenTag(tagName);
                    addAttribute("album", thesaurus.getSubsetKey().getSubsetName());
                    endOpenTag();
                }
                List<IllustrationExtractInfo> list = extraitAlbumResult.getIllustrationExtractInfoList(j);
                for (IllustrationExtractInfo illustrationExtractInfo : list) {
                    illustrationXMLPart.addIllustration(illustrationExtractInfo);
                }
                if (withTag) {
                    closeTag(tagName);
                }
            }
        }
    }

}
